@@ -3,7 +3,7 @@
  *  A simple stop watch class. */
 
 /*
- *  GiNaC Copyright (C) 1999-2005 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,14 @@
 #ifndef TIMER_H
 #define TIMER_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#ifdef HAVE_RUSAGE
 #include <sys/resource.h>
+#else
+#include <ctime>
+#endif
 
 class timer {
 public:
@@ -35,7 +42,11 @@ public:
 	bool running();
 private:
 	bool on;
+#ifdef HAVE_RUSAGE
 	struct rusage used1, used2;
+#else
+	std::clock_t used1, used2;
+#endif
 };
 
 #endif // ndef TIMER_H
